@@ -149,7 +149,7 @@ distribution set (it is not installed as part of the module.
 
   my $progress = Term::ProgressBar->new({name  => 'Powers',
                                          count => $max,
-                                         ETA   => linear, });
+                                         ETA   => 'linear', });
   $progress->max_update_rate(1);
   my $next_update = 0;
 
@@ -254,7 +254,7 @@ use constant DEBUG => 0;
 
 use vars qw($PACKAGE $VERSION);
 $PACKAGE = 'Term-ProgressBar';
-$VERSION = '2.11';
+$VERSION = '2.12';
 
 # ----------------------------------
 # CLASS CONSTRUCTION
@@ -585,6 +585,24 @@ action, and not in action, respectively.
 
 =back
 
+=head2 Configuration
+
+=over 4
+
+=item lbrack
+
+Left bracket ( defaults to [ )
+
+ $progress->lbrack('<');
+
+=item rbrack
+
+Right bracket ( defaults to ] )
+
+ $progress->rbrack('>');
+
+=back
+
 =cut
 
 # Private Scalar Components
